@@ -27,6 +27,7 @@ import shutil
 import functools
 import collections
 
+import sip
 from PyQt5.QtCore import (pyqtSlot, pyqtSignal, QObject, QTimer,
                           Qt, QVariant, QAbstractListModel, QModelIndex, QUrl)
 from PyQt5.QtGui import QDesktopServices
@@ -534,6 +535,22 @@ class DownloadItem(QObject):
             self._filename = create_full_filename(
                 self.basename, os.path.join(download_dir(), filename))
 
+        # At this point, we have a misconfigured XDG_DOWNLOAd_DIR, as
+        # download_dir() + filename is still no absolute path.
+        # The config value is checked for "absoluteness", but
+        # ~/.config/user-dirs.dirs may be misconfigured and a non-absolute path
+        # may be set for XDG_DOWNLOAD_DIR
+        if self._filename is None:
+            message.error(
+                self._win_id,
+                "XDG_DOWNLOAD_DIR points to a relative path - please check"
+                " your ~/.config/user-dirs.dirs. The download is saved in"
+                " your home directory.",
+            )
+            # fall back to $HOME as download_dir
+            self._filename = create_full_filename(
+                self.basename, os.path.expanduser(os.path.join('~', filename)))
+
         self.basename = os.path.basename(self._filename)
         last_used_directory = os.path.dirname(self._filename)
 
@@ -774,7 +791,28 @@ class DownloadManager(QAbstractListModel):
         # https://bugreports.qt.io/browse/QTBUG-42757
         request.setAttribute(QNetworkRequest.CacheLoadControlAttribute,
                              QNetworkRequest.AlwaysNetwork)
-        suggested_fn = urlutils.filename_from_url(request.url())
+
+        if request.url().scheme().lower() != 'data':
+            suggested_fn = urlutils.filename_from_url(request.url())
+        else:
+            # We might be downloading a binary blob embedded on a page or even
+            # generated dynamically via javascript. We try to figure out a more
+            # sensible name than the base64 content of the data.
+            origin = request.originatingObject()
+            try:
+                origin_url = origin.url()
+            except AttributeError:
+                # Raised either if origin is None or some object that doesn't
+                # have its own url. We're probably fine with a default fallback
+                # then.
+                suggested_fn = 'binary blob'
+            else:
+                # Use the originating URL as a base for the filename (works
+                # e.g. for pdf.js).
+                suggested_fn = urlutils.filename_from_url(origin_url)
+
+        if suggested_fn is None:
+            suggested_fn = 'qutebrowser-download'
 
         # We won't need a question if a filename or fileobj is already given
         if fileobj is None and filename is None:
@@ -911,22 +949,30 @@ class DownloadManager(QAbstractListModel):
 
     @cmdutils.register(instance='download-manager', scope='window',
                        count='count')
-    def download_cancel(self, count=0):
+    def download_cancel(self, all_=False, count=0):
         """Cancel the last/[count]th download.
 
         Args:
+            all_: Cancel all running downloads
             count: The index of the download to cancel.
         """
-        try:
-            download = self.downloads[count - 1]
-        except IndexError:
-            self.raise_no_download(count)
-        if download.done:
-            if not count:
-                count = len(self.downloads)
-            raise cmdexc.CommandError("Download {} is already done!"
-                                      .format(count))
-        download.cancel()
+        if all_:
+            # We need to make a copy as we're indirectly mutating
+            # self.downloads here
+            for download in self.downloads[:]:
+                if not download.done:
+                    download.cancel()
+        else:
+            try:
+                download = self.downloads[count - 1]
+            except IndexError:
+                self.raise_no_download(count)
+            if download.done:
+                if not count:
+                    count = len(self.downloads)
+                raise cmdexc.CommandError("Download {} is already done!"
+                                        .format(count))
+            download.cancel()
 
     @cmdutils.register(instance='download-manager', scope='window',
                        count='count')
@@ -934,7 +980,7 @@ class DownloadManager(QAbstractListModel):
         """Delete the last/[count]th download from disk.
 
         Args:
-            count: The index of the download to cancel.
+            count: The index of the download to delete.
         """
         try:
             download = self.downloads[count - 1]
@@ -953,7 +999,7 @@ class DownloadManager(QAbstractListModel):
         """Open the last/[count]th download.
 
         Args:
-            count: The index of the download to cancel.
+            count: The index of the download to open.
         """
         try:
             download = self.downloads[count - 1]
@@ -971,7 +1017,7 @@ class DownloadManager(QAbstractListModel):
         """Retry the first failed/[count]th download.
 
         Args:
-            count: The index of the download to cancel.
+            count: The index of the download to retry.
         """
         if count:
             try:
@@ -1057,12 +1103,10 @@ class DownloadManager(QAbstractListModel):
         """Remove the last/[count]th download from the list.
 
         Args:
-            all_: Deprecated argument for removing all finished downloads.
-            count: The index of the download to cancel.
+            all_: Remove all finished downloads.
+            count: The index of the download to remove.
         """
         if all_:
-            message.warning(self._win_id, ":download-remove --all is "
-                            "deprecated - use :download-clear instead!")
             self.download_clear()
         else:
             try:
@@ -1087,6 +1131,9 @@ class DownloadManager(QAbstractListModel):
 
     def remove_item(self, download):
         """Remove a given download."""
+        if sip.isdeleted(self):
+            # https://github.com/The-Compiler/qutebrowser/issues/1242
+            return
         try:
             idx = self.downloads.index(download)
         except ValueError:
