@@ -29,9 +29,16 @@ from qutebrowser.utils import utils
 
 class PDFJSNotFound(Exception):
 
-    """Raised when no pdf.js installation is found."""
+    """Raised when no pdf.js installation is found.
 
-    pass
+    Attributes:
+        path: path of the file that was requested but not found.
+    """
+
+    def __init__(self, path):
+        self.path = path
+        message = "Path '{}' not found".format(path)
+        super().__init__(message)
 
 
 def generate_pdfjs_page(url):
@@ -63,54 +70,63 @@ def _generate_pdfjs_script(url):
 
 
 def fix_urls(asset):
-    """Take a html page and replace each relative URL wth an absolute.
+    """Take a html page and replace each relative URL with an absolute.
 
     This is specialized for pdf.js files and not a general purpose function.
 
     Args:
         asset: js file or html page as string.
     """
-    new_urls = {
-        'viewer.css': 'qute://pdfjs/web/viewer.css',
-        'compatibility.js': 'qute://pdfjs/web/compatibility.js',
-        'locale/locale.properties':
-            'qute://pdfjs/web/locale/locale.properties',
-        'l10n.js': 'qute://pdfjs/web/l10n.js',
-        '../build/pdf.js': 'qute://pdfjs/build/pdf.js',
-        'debugger.js': 'qute://pdfjs/web/debugger.js',
-        'viewer.js': 'qute://pdfjs/web/viewer.js',
-        'compressed.tracemonkey-pldi-09.pdf': '',
-        './images/': 'qute://pdfjs/web/images/',
-        '../build/pdf.worker.js': 'qute://pdfjs/build/pdf.worker.js',
-        '../web/cmaps/': 'qute://pdfjs/web/cmaps/',
-    }
-    for original, new in new_urls.items():
+    new_urls = [
+        ('viewer.css', 'qute://pdfjs/web/viewer.css'),
+        ('compatibility.js', 'qute://pdfjs/web/compatibility.js'),
+        ('locale/locale.properties',
+            'qute://pdfjs/web/locale/locale.properties'),
+        ('l10n.js', 'qute://pdfjs/web/l10n.js'),
+        ('../build/pdf.js', 'qute://pdfjs/build/pdf.js'),
+        ('debugger.js', 'qute://pdfjs/web/debugger.js'),
+        ('viewer.js', 'qute://pdfjs/web/viewer.js'),
+        ('compressed.tracemonkey-pldi-09.pdf', ''),
+        ('./images/', 'qute://pdfjs/web/images/'),
+        ('../build/pdf.worker.js', 'qute://pdfjs/build/pdf.worker.js'),
+        ('../web/cmaps/', 'qute://pdfjs/web/cmaps/'),
+    ]
+    for original, new in new_urls:
         asset = asset.replace(original, new)
     return asset
 
 
 SYSTEM_PDFJS_PATHS = [
-    '/usr/share/pdf.js/',  # Debian pdf.js-common
-    '/usr/share/javascript/pdf/',  # Debian libjs-pdf
-    os.path.expanduser('~/.local/share/qutebrowser/pdfjs/'),  # fallback
+    # Debian pdf.js-common
+    # Arch Linux pdfjs (AUR)
+    '/usr/share/pdf.js/',
+    # Debian libjs-pdf
+    '/usr/share/javascript/pdf/',
+    # fallback
+    os.path.expanduser('~/.local/share/qutebrowser/pdfjs/'),
 ]
 
 
-def get_pdfjs_res(path):
+def get_pdfjs_res_and_path(path):
     """Get a pdf.js resource in binary format.
 
+    Returns a (content, path) tuple, where content is the file content and path
+    is the path where the file was found. If path is None, the bundled version
+    was used.
+
     Args:
         path: The path inside the pdfjs directory.
     """
     path = path.lstrip('/')
     content = None
+    file_path = None
 
     # First try a system wide installation
     # System installations might strip off the 'build/' or 'web/' prefixes.
     # qute expects them, so we need to adjust for it.
     names_to_try = [path, _remove_prefix(path)]
     for system_path in SYSTEM_PDFJS_PATHS:
-        content = _read_from_system(system_path, names_to_try)
+        content, file_path = _read_from_system(system_path, names_to_try)
         if content is not None:
             break
 
@@ -120,15 +136,25 @@ def get_pdfjs_res(path):
         try:
             content = utils.read_file(res_path, binary=True)
         except FileNotFoundError:
-            raise PDFJSNotFound
+            raise PDFJSNotFound(path) from None
 
     try:
         # Might be script/html or might be binary
         text_content = content.decode('utf-8')
     except UnicodeDecodeError:
-        return content
+        return (content, file_path)
     text_content = fix_urls(text_content)
-    return text_content.encode('utf-8')
+    return (text_content.encode('utf-8'), file_path)
+
+
+def get_pdfjs_res(path):
+    """Get a pdf.js resource in binary format.
+
+    Args:
+        path: The path inside the pdfjs directory.
+    """
+    content, _path = get_pdfjs_res_and_path(path)
+    return content
 
 
 def _remove_prefix(path):
@@ -147,10 +173,13 @@ def _remove_prefix(path):
 def _read_from_system(system_path, names):
     """Try to read a file with one of the given names in system_path.
 
+    Returns a (content, path) tuple, where the path is the filepath that was
+    used.
+
     Each file in names is considered equal, the first file that is found
     is read and its binary content returned.
 
-    Returns None if no file could be found
+    Returns (None, None) if no file could be found
 
     Args:
         system_path: The folder where the file should be searched.
@@ -158,11 +187,12 @@ def _read_from_system(system_path, names):
     """
     for name in names:
         try:
-            with open(os.path.join(system_path, name), 'rb') as f:
-                return f.read()
+            full_path = os.path.join(system_path, name)
+            with open(full_path, 'rb') as f:
+                return (f.read(), full_path)
         except OSError:
             continue
-    return None
+    return (None, None)
 
 
 def is_available():
